==> 0.0.1%2B1.tar.gz: lib/models/IR5Member.dart <==
// --------------------------------------------------------------------------------

import 'package:json_annotation/json_annotation.dart';

part 'IR5Member.g.dart';

@JsonSerializable()
class IR5Member {
  IR5Member({
    required this.Num,
    required this.NumCarte,
    this.NumCarte_Parent,
    this.ExtRef,
    this.Barcode,
    this.NationalNumber,
    required this.Nom,
    this.Prenom,
    this.Description,
    this.MEMBER_TYPE,
    this.CATEG,
    this.Tags,
    this.Box,
    required this.Language,
    required this.AutoBlocage,
    this.Limit,
    this.Civilite,
    this.Mention,
    this.Attention,
    this.RUE,
    this.CP,
    this.LOCALITE,
    this.PAYS,
    this.TEL1,
    this.TEL2,
    this.FAX,
    this.MOBILE,
    this.EMAIL,
    this.HomePage,
    this.CodeTVA,
    this.TVA,
    this.BankIBAN,
    this.BankBIC,
    this.BankMandateId,
    this.BankMandateDte,
    this.CCard,
    this.CCard_Holder,
    this.CCard_Nr,
    this.CCard_ExpirationDATE,
    this.FACT_MODE,
    this.FACT_ADRESS,
    this.FACT_Text,
    this.FACT_FLAGS,
    this.BirthDay,
    this.MEMO,
    this.Flags,
    this.Visites,
    this.AnteVisite,
    this.LastVisite,
    this.TokenPay,
    this.Discount,
    this.Caution,
    this.Solde,
    this.TotPoints,
    this.TblTotalTTC,
    this.TblTotalPay,
    this.TblTotalCpteCli,
    this.TblNewTotPoints,
    this.TblBarCode,
    this.Expiration,
    this.DateModif,
    this.DateCreation,
  });

  factory IR5Member.fromJson(Map<String, dynamic>? json) => _$IR5MemberFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5MemberToJson(this);

  @JsonKey(defaultValue: 0)
  final num Num;
  @JsonKey(defaultValue: '')
  final String NumCarte;
  final String? NumCarte_Parent;
  final String? ExtRef;
  final String? Barcode;
  final String? NationalNumber;
  @JsonKey(defaultValue: '')
  final String Nom;
  final String? Prenom;

  /** Just a free Description:
   * Can be use to store additional field in any text format
   * ex:
   * { Ranking : 1, Sports : [Footbal,BallePelote] }
   */
  final String? Description;

  /** Member Type
   * Customer Type : (for mailing selection)
   */
  final String? MEMBER_TYPE;

  /** Member Categ
   * Customer Categ: Free Use
   */
  final String? CATEG;

  /** Free Tags or Labels semicolumn separated */
  final String? Tags;
  final String? Box;

  /** Language Index :
   * 0 : French (Default)
   * 1 : Dutch
   * 2 : English
   * 3 : German
   * 4 : Spanish
   */
  @JsonKey(defaultValue: 0)
  final num Language;

  /** Member Credit Mode Limitation
   * Customer Lock [No,Locked,Limited to its Provision]
   */
  @JsonKey(defaultValue: 'Locked')
  final String AutoBlocage;
  final num? Limit;
  final String? Civilite;
  final String? Mention;
  final String? Attention;
  final String? RUE;
  final String? CP;
  final String? LOCALITE;
  final String? PAYS;
  final String? TEL1;
  final String? TEL2;
  final String? FAX;
  final String? MOBILE;
  final String? EMAIL;
  final String? HomePage;
  final String? CodeTVA;
  final String? TVA;
  final String? BankIBAN;
  final String? BankBIC;
  final String? BankMandateId;
  final String? BankMandateDte;
  final String? CCard;
  final String? CCard_Holder;
  final String? CCard_Nr;
  final String? CCard_ExpirationDATE;

  /** Member Invoice Mode
   * 1 - Detailed Uptake Invoice
   * 2 - Detailed Ticket1 Invoice (without Uptakes)
   * 4 - Detailed Ticket2 Invoice (without Uptakes)
   * 3 - Global Invoice with Generic Text (choosen by the customer)
   * 0 - No Monthly Invoice
   */
  final String? FACT_MODE;

  /** Member Invoice Address
   * Invoice Address
   */
  final String? FACT_ADRESS;

  /** Member Invoice Text
   * Global Invoice Text
   */
  final String? FACT_Text;

  /** Member Invoice Flags
   * Flag = Mail Billing Printer (Print, Mail)
   */
  final num? FACT_FLAGS;
  final String? BirthDay;
  final String? MEMO;

  /** Member Flags
   * Flag = Type Client = Golden or Suspended
   */
  final num? Flags;

  /** Member Visits
   * Number of days the Member came
   */
  final num? Visites;
  final String? AnteVisite;
  final String? LastVisite;
  final String? TokenPay;

  /** Member DISCOUNT */
  final num? Discount;
  final num? Caution;
  final num? Solde;
  final num? TotPoints;
  final num? TblTotalTTC;
  final num? TblTotalPay;
  final num? TblTotalCpteCli;
  final num? TblNewTotPoints;
  final String? TblBarCode;
  final String? Expiration;
  final String? DateModif;
  final String? DateCreation;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Member.dart <==
// --------------------------------------------------------------------------------

import 'package:json_annotation/json_annotation.dart';

part 'IR5Member.g.dart';

@JsonSerializable()
class IR5Member {
  IR5Member({
    required this.Num,
    required this.NumCarte,
    this.NumCarte_Parent,
    this.ExtRef,
    this.Barcode,
    this.NationalNumber,
    required this.Nom,
    this.Prenom,
    this.Description,
    this.MEMBER_TYPE,
    this.CATEG,
    this.Tags,
    this.Box,
    required this.Language,
    required this.AutoBlocage,
    this.Limit,
    this.Civilite,
    this.Mention,
    this.Attention,
    this.RUE,
    this.CP,
    this.LOCALITE,
    this.PAYS,
    this.TEL1,
    this.TEL2,
    this.FAX,
    this.MOBILE,
    this.EMAIL,
    this.HomePage,
    this.CodeTVA,
    this.TVA,
    this.BankIBAN,
    this.BankBIC,
    this.BankMandateId,
    this.BankMandateDte,
    this.CCard,
    this.CCard_Holder,
    this.CCard_Nr,
    this.CCard_ExpirationDATE,
    this.FACT_MODE,
    this.FACT_ADRESS,
    this.FACT_Text,
    this.FACT_FLAGS,
    this.BirthDay,
    this.MEMO,
    this.Flags,
    this.Visites,
    this.AnteVisite,
    this.LastVisite,
    this.TokenPay,
    this.Discount,
    this.Caution,
    this.Solde,
    this.TotPoints,
    this.TblTotalTTC,
    this.TblTotalPay,
    this.TblTotalCpteCli,
    this.TblNewTotPoints,
    this.TblBarCode,
    this.Expiration,
    this.DateModif,
    this.DateCreation,
  });

  factory IR5Member.fromJson(Map<String, dynamic>? json) =>
      _$IR5MemberFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5MemberToJson(this);

  @JsonKey(defaultValue: 0)
  final num Num;
  @JsonKey(defaultValue: '')
  final String NumCarte;
  final String? NumCarte_Parent;
  final String? ExtRef;
  final String? Barcode;
  final String? NationalNumber;
  @JsonKey(defaultValue: '')
  final String Nom;
  final String? Prenom;

  /** Just a free Description:
   * Can be use to store additional field in any text format
   * ex:
   * { Ranking : 1, Sports : [Footbal,BallePelote] }
   */
  final String? Description;

  /** Member Type
   * Customer Type : (for mailing selection)
   */
  final String? MEMBER_TYPE;

  /** Member Categ
   * Customer Categ: Free Use
   */
  final String? CATEG;

  /** Free Tags or Labels semicolumn separated */
  final String? Tags;
  final String? Box;

  /** Language Index :
   * 0 : French (Default)
   * 1 : Dutch
   * 2 : English
   * 3 : German
   * 4 : Spanish
   */
  @JsonKey(defaultValue: 0)
  final num Language;

  /** Member Credit Mode Limitation
   * Customer Lock [No,Locked,Limited to its Provision]
   */
  @JsonKey(defaultValue: 'Locked')
  final String AutoBlocage;
  final num? Limit;
  final String? Civilite;
  final String? Mention;
  final String? Attention;
  final String? RUE;
  final String? CP;
  final String? LOCALITE;
  final String? PAYS;
  final String? TEL1;
  final String? TEL2;
  final String? FAX;
  final String? MOBILE;
  final String? EMAIL;
  final String? HomePage;
  final String? CodeTVA;
  final String? TVA;
  final String? BankIBAN;
  final String? BankBIC;
  final String? BankMandateId;
  final String? BankMandateDte;
  final String? CCard;
  final String? CCard_Holder;
  final String? CCard_Nr;
  final String? CCard_ExpirationDATE;

  /** Member Invoice Mode
   * 1 - Detailed Uptake Invoice
   * 2 - Detailed Ticket1 Invoice (without Uptakes)
   * 4 - Detailed Ticket2 Invoice (without Uptakes)
   * 3 - Global Invoice with Generic Text (choosen by the customer)
   * 0 - No Monthly Invoice
   */
  final String? FACT_MODE;

  /** Member Invoice Address
   * Invoice Address
   */
  final String? FACT_ADRESS;

  /** Member Invoice Text
   * Global Invoice Text
   */
  final String? FACT_Text;

  /** Member Invoice Flags
   * Flag = Mail Billing Printer (Print, Mail)
   */
  final num? FACT_FLAGS;
  final String? BirthDay;
  final String? MEMO;

  /** Member Flags
   * Flag = Type Client = Golden or Suspended
   */
  final num? Flags;

  /** Member Visits
   * Number of days the Member came
   */
  final num? Visites;
  final String? AnteVisite;
  final String? LastVisite;
  final String? TokenPay;

  /** Member DISCOUNT */
  final num? Discount;
  final num? Caution;
  final num? Solde;
  final num? TotPoints;
  final num? TblTotalTTC;
  final num? TblTotalPay;
  final num? TblTotalCpteCli;
  final num? TblNewTotPoints;
  final String? TblBarCode;
  final String? Expiration;
  final String? DateModif;
  final String? DateCreation;
}
